Index: trunk/src/org/openstreetmap/josm/actions/downloadtasks/DownloadNotesUrlIdTask.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/downloadtasks/DownloadNotesUrlIdTask.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/actions/downloadtasks/DownloadNotesUrlIdTask.java	(revision 8346)
@@ -12,5 +12,5 @@
 public class DownloadNotesUrlIdTask extends DownloadNotesTask {
 
-    private final String URL_ID_PATTERN = "https?://www\\.(osm|openstreetmap)\\.org/note/(\\p{Digit}+).*";
+    private static final String URL_ID_PATTERN = "https?://www\\.(osm|openstreetmap)\\.org/note/(\\p{Digit}+).*";
 
     @Override
Index: trunk/src/org/openstreetmap/josm/actions/mapmode/DrawAction.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/mapmode/DrawAction.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/actions/mapmode/DrawAction.java	(revision 8346)
@@ -73,9 +73,12 @@
  */
 public class DrawAction extends MapMode implements MapViewPaintable, SelectionChangedListener, KeyPressReleaseListener, ModifierListener {
+
+    private static final Color ORANGE_TRANSPARENT = new Color(Color.ORANGE.getRed(),Color.ORANGE.getGreen(),Color.ORANGE.getBlue(),128);
+    private static final double PHI = Math.toRadians(90);
+
     private final Cursor cursorJoinNode;
     private final Cursor cursorJoinWay;
 
     private transient Node lastUsedNode = null;
-    private static final double PHI = Math.toRadians(90);
     private double toleranceMultiplier;
 
@@ -116,4 +119,8 @@
     private static int snapToIntersectionThreshold;
 
+    /**
+     * Constructs a new {@code DrawAction}.
+     * @param mapFrame Map frame
+     */
     public DrawAction(MapFrame mapFrame) {
         super(tr("Draw"), "node/autonode", tr("Draw nodes"),
@@ -1323,5 +1330,4 @@
 
         private JCheckBoxMenuItem checkBox;
-        public final Color ORANGE_TRANSPARENT = new Color(Color.ORANGE.getRed(),Color.ORANGE.getGreen(),Color.ORANGE.getBlue(),128);
 
         public void init() {
Index: trunk/src/org/openstreetmap/josm/command/PurgeCommand.java
===================================================================
--- trunk/src/org/openstreetmap/josm/command/PurgeCommand.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/command/PurgeCommand.java	(revision 8346)
@@ -38,5 +38,5 @@
     protected Storage<PrimitiveData> makeIncompleteData;
 
-    protected Map<PrimitiveId, PrimitiveData> makeIncompleteData_byPrimId;
+    protected Map<PrimitiveId, PrimitiveData> makeIncompleteDataByPrimId;
 
     protected final ConflictCollection purgedConflicts = new ConflictCollection();
@@ -69,5 +69,5 @@
     protected final void saveIncomplete(Collection<OsmPrimitive> makeIncomplete) {
         makeIncompleteData = new Storage<>(new Storage.PrimitiveIdHash());
-        makeIncompleteData_byPrimId = makeIncompleteData.foreignKey(new Storage.PrimitiveIdHash());
+        makeIncompleteDataByPrimId = makeIncompleteData.foreignKey(new Storage.PrimitiveIdHash());
 
         for (OsmPrimitive osm : makeIncomplete) {
@@ -86,5 +86,5 @@
             for (int i=toPurge.size()-1; i>=0; --i) {
                 OsmPrimitive osm = toPurge.get(i);
-                if (makeIncompleteData_byPrimId.containsKey(osm)) {
+                if (makeIncompleteDataByPrimId.containsKey(osm)) {
                     // we could simply set the incomplete flag
                     // but that would not free memory in case the
@@ -121,5 +121,5 @@
 
         for (OsmPrimitive osm : toPurge) {
-            PrimitiveData data = makeIncompleteData_byPrimId.get(osm);
+            PrimitiveData data = makeIncompleteDataByPrimId.get(osm);
             if (data != null) {
                 if (ds.getPrimitiveById(osm) != osm)
Index: trunk/src/org/openstreetmap/josm/data/osm/visitor/paint/StyledMapRenderer.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/osm/visitor/paint/StyledMapRenderer.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/data/osm/visitor/paint/StyledMapRenderer.java	(revision 8346)
@@ -108,5 +108,5 @@
          * 'prev' to the next point.
          */
-        private int x_prev0, y_prev0;
+        private int xPrev0, yPrev0;
 
         public OffsetIterator(List<Node> nodes, float offset) {
@@ -130,5 +130,5 @@
                 ++idx;
                 if (prev != null) {
-                    return new Point(x_prev0 + current.x - prev.x, y_prev0 + current.y - prev.y);
+                    return new Point(xPrev0 + current.x - prev.x, yPrev0 + current.y - prev.y);
                 } else {
                     return current;
@@ -152,6 +152,6 @@
                 ++idx;
                 prev = current;
-                x_prev0 = x_current0;
-                y_prev0 = y_current0;
+                xPrev0 = x_current0;
+                yPrev0 = y_current0;
                 return new Point(x_current0, y_current0);
             } else {
@@ -166,17 +166,17 @@
                     ++idx;
                     prev = current;
-                    x_prev0 = x_current0;
-                    y_prev0 = y_current0;
+                    xPrev0 = x_current0;
+                    yPrev0 = y_current0;
                     return new Point(x_current0, y_current0);
                 }
 
-                int m = dx_next*(y_current0 - y_prev0) - dy_next*(x_current0 - x_prev0);
-
-                int cx_ = x_prev0 + Math.round((float)m * dx_prev / det);
-                int cy_ = y_prev0 + Math.round((float)m * dy_prev / det);
+                int m = dx_next*(y_current0 - yPrev0) - dy_next*(x_current0 - xPrev0);
+
+                int cx_ = xPrev0 + Math.round((float)m * dx_prev / det);
+                int cy_ = yPrev0 + Math.round((float)m * dy_prev / det);
                 ++idx;
                 prev = current;
-                x_prev0 = x_current0;
-                y_prev0 = y_current0;
+                xPrev0 = x_current0;
+                yPrev0 = y_current0;
                 return new Point(cx_, cy_);
             }
@@ -207,5 +207,5 @@
                 return 1;
 
-            int d0 = Float.compare(this.style.major_z_index, other.style.major_z_index);
+            int d0 = Float.compare(this.style.majorZIndex, other.style.majorZIndex);
             if (d0 != 0)
                 return d0;
@@ -218,5 +218,5 @@
                 return -1;
 
-            int dz = Float.compare(this.style.z_index, other.style.z_index);
+            int dz = Float.compare(this.style.zIndex, other.style.zIndex);
             if (dz != 0)
                 return dz;
@@ -235,5 +235,5 @@
                 return -1;
 
-            return Float.compare(this.style.object_z_index, other.style.object_z_index);
+            return Float.compare(this.style.objectZIndex, other.style.objectZIndex);
         }
     }
Index: trunk/src/org/openstreetmap/josm/data/projection/AbstractProjection.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/projection/AbstractProjection.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/data/projection/AbstractProjection.java	(revision 8346)
@@ -26,8 +26,8 @@
     protected Datum datum;
     protected Proj proj;
-    protected double x_0 = 0.0;     /* false easting (in meters) */
-    protected double y_0 = 0.0;     /* false northing (in meters) */
-    protected double lon_0 = 0.0;   /* central meridian */
-    protected double k_0 = 1.0;     /* general scale factor */
+    protected double x0 = 0.0;     /* false easting (in meters) */
+    protected double y0 = 0.0;     /* false northing (in meters) */
+    protected double lon0 = 0.0;   /* central meridian */
+    protected double k0 = 1.0;     /* general scale factor */
 
     public final Ellipsoid getEllipsoid() {
@@ -48,17 +48,17 @@
 
     public final double getFalseEasting() {
-        return x_0;
+        return x0;
     }
 
     public final double getFalseNorthing() {
-        return y_0;
+        return y0;
     }
 
     public final double getCentralMeridian() {
-        return lon_0;
+        return lon0;
     }
 
     public final double getScaleFactor() {
-        return k_0;
+        return k0;
     }
 
@@ -66,12 +66,12 @@
     public EastNorth latlon2eastNorth(LatLon ll) {
         ll = datum.fromWGS84(ll);
-        double[] en = proj.project(Math.toRadians(ll.lat()), Math.toRadians(ll.lon() - lon_0));
-        return new EastNorth(ellps.a * k_0 * en[0] + x_0, ellps.a * k_0 * en[1] + y_0);
+        double[] en = proj.project(Math.toRadians(ll.lat()), Math.toRadians(ll.lon() - lon0));
+        return new EastNorth(ellps.a * k0 * en[0] + x0, ellps.a * k0 * en[1] + y0);
     }
 
     @Override
     public LatLon eastNorth2latlon(EastNorth en) {
-        double[] latlon_rad = proj.invproject((en.east() - x_0) / ellps.a / k_0, (en.north() - y_0) / ellps.a / k_0);
-        LatLon ll = new LatLon(Math.toDegrees(latlon_rad[0]), Math.toDegrees(latlon_rad[1]) + lon_0);
+        double[] latlon_rad = proj.invproject((en.east() - x0) / ellps.a / k0, (en.north() - y0) / ellps.a / k0);
+        LatLon ll = new LatLon(Math.toDegrees(latlon_rad[0]), Math.toDegrees(latlon_rad[1]) + lon0);
         return datum.toWGS84(ll);
     }
Index: trunk/src/org/openstreetmap/josm/data/projection/CustomProjection.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/projection/CustomProjection.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/data/projection/CustomProjection.java	(revision 8346)
@@ -175,17 +175,17 @@
             String s = parameters.get(Param.x_0.key);
             if (s != null) {
-                this.x_0 = parseDouble(s, Param.x_0.key);
+                this.x0 = parseDouble(s, Param.x_0.key);
             }
             s = parameters.get(Param.y_0.key);
             if (s != null) {
-                this.y_0 = parseDouble(s, Param.y_0.key);
+                this.y0 = parseDouble(s, Param.y_0.key);
             }
             s = parameters.get(Param.lon_0.key);
             if (s != null) {
-                this.lon_0 = parseAngle(s, Param.lon_0.key);
+                this.lon0 = parseAngle(s, Param.lon_0.key);
             }
             s = parameters.get(Param.k_0.key);
             if (s != null) {
-                this.k_0 = parseDouble(s, Param.k_0.key);
+                this.k0 = parseDouble(s, Param.k_0.key);
             }
             s = parameters.get(Param.bounds.key);
@@ -386,13 +386,13 @@
         s = parameters.get(Param.lat_0.key);
         if (s != null) {
-            projParams.lat_0 = parseAngle(s, Param.lat_0.key);
+            projParams.lat0 = parseAngle(s, Param.lat_0.key);
         }
         s = parameters.get(Param.lat_1.key);
         if (s != null) {
-            projParams.lat_1 = parseAngle(s, Param.lat_1.key);
+            projParams.lat1 = parseAngle(s, Param.lat_1.key);
         }
         s = parameters.get(Param.lat_2.key);
         if (s != null) {
-            projParams.lat_2 = parseAngle(s, Param.lat_2.key);
+            projParams.lat2 = parseAngle(s, Param.lat_2.key);
         }
         proj.initialize(projParams);
Index: trunk/src/org/openstreetmap/josm/data/projection/proj/LambertConformalConic.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/projection/proj/LambertConformalConic.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/data/projection/proj/LambertConformalConic.java	(revision 8346)
@@ -15,4 +15,5 @@
 import static org.openstreetmap.josm.tools.I18n.tr;
 
+import org.openstreetmap.josm.data.projection.CustomProjection.Param;
 import org.openstreetmap.josm.data.projection.Ellipsoid;
 import org.openstreetmap.josm.data.projection.ProjectionConfigurationException;
@@ -60,5 +61,5 @@
      * projection factor
      */
-    protected double F;
+    protected double f;
     /**
      * radius of the parallel of latitude of the false origin (2SP) or at
@@ -76,10 +77,10 @@
         ellps = params.ellps;
         e = ellps.e;
-        if (params.lat_0 == null)
-            throw new ProjectionConfigurationException(tr("Parameter ''{0}'' required.", "lat_0"));
-        if (params.lat_1 != null && params.lat_2 != null) {
-            initialize2SP(params.lat_0, params.lat_1, params.lat_2);
+        if (params.lat0 == null)
+            throw new ProjectionConfigurationException(tr("Parameter ''{0}'' required.", Param.lat_0.key));
+        if (params.lat1 != null && params.lat2 != null) {
+            initialize2SP(params.lat0, params.lat1, params.lat2);
         } else {
-            initialize1SP(params.lat_0);
+            initialize1SP(params.lat0);
         }
     }
@@ -103,6 +104,6 @@
 
         n  = (log(m1) - log(m2)) / (log(t1) - log(t2));
-        F  = m1 / (n * pow(t1, n));
-        r0 = F * pow(tf, n);
+        f  = m1 / (n * pow(t1, n));
+        r0 = f * pow(tf, n);
     }
 
@@ -120,6 +121,6 @@
 
         n = sin(lat_0_rad);
-        F  = m0 / (n * pow(t0, n));
-        r0 = F * pow(t0, n);
+        f  = m0 / (n * pow(t0, n));
+        r0 = f * pow(t0, n);
     }
 
@@ -153,5 +154,5 @@
         double sinphi = sin(phi);
         double L = (0.5*log((1+sinphi)/(1-sinphi))) - e/2*log((1+e*sinphi)/(1-e*sinphi));
-        double r = F*exp(-n*L);
+        double r = f*exp(-n*L);
         double gamma = n*lambda;
         double X = r*sin(gamma);
@@ -165,5 +166,5 @@
         double gamma = atan(east / (r0-north));
         double lambda = gamma/n;
-        double latIso = (-1/n) * log(abs(r/F));
+        double latIso = (-1/n) * log(abs(r/f));
         double phi = ellps.latitude(latIso, e, epsilon);
         return new double[] { phi, lambda };
Index: trunk/src/org/openstreetmap/josm/data/projection/proj/ProjParameters.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/projection/proj/ProjParameters.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/data/projection/proj/ProjParameters.java	(revision 8346)
@@ -11,7 +11,6 @@
     public Ellipsoid ellps;
 
-    public Double lat_0;
-    public Double lat_1;
-    public Double lat_2;
-
+    public Double lat0;
+    public Double lat1;
+    public Double lat2;
 }
Index: trunk/src/org/openstreetmap/josm/data/projection/proj/SwissObliqueMercator.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/projection/proj/SwissObliqueMercator.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/data/projection/proj/SwissObliqueMercator.java	(revision 8346)
@@ -35,5 +35,5 @@
     private double alpha;
     private double b0;
-    private double K;
+    private double k;
 
     private static final double EPSILON = 1e-11;
@@ -41,8 +41,8 @@
     @Override
     public void initialize(ProjParameters params) throws ProjectionConfigurationException {
-        if (params.lat_0 == null)
+        if (params.lat0 == null)
             throw new ProjectionConfigurationException(tr("Parameter ''{0}'' required.", "lat_0"));
         ellps = params.ellps;
-        initialize(params.lat_0);
+        initialize(params.lat0);
     }
 
@@ -52,5 +52,5 @@
         alpha = sqrt(1 + (ellps.eb2 * pow(cos(phi0), 4)));
         b0 = asin(sin(phi0) / alpha);
-        K = log(tan(PI / 4 + b0 / 2)) - alpha
+        k = log(tan(PI / 4 + b0 / 2)) - alpha
             * log(tan(PI / 4 + phi0 / 2)) + alpha * ellps.e / 2
             * log((1 + ellps.e * sin(phi0)) / (1 - ellps.e * sin(phi0)));
@@ -71,5 +71,5 @@
 
         double S = alpha * log(tan(PI / 4 + phi / 2)) - alpha * ellps.e / 2
-            * log((1 + ellps.e * sin(phi)) / (1 - ellps.e * sin(phi))) + K;
+            * log((1 + ellps.e * sin(phi)) / (1 - ellps.e * sin(phi))) + k;
         double b = 2 * (atan(exp(S)) - PI / 4);
         double l = alpha * lambda;
@@ -94,5 +94,5 @@
         double lambda = l / alpha;
         double phi = b;
-        double S = 0;
+        double s = 0;
 
         double prevPhi = -1000;
@@ -103,7 +103,7 @@
                 throw new RuntimeException("Two many iterations");
             prevPhi = phi;
-            S = 1 / alpha * (log(tan(PI / 4 + b / 2)) - K) + ellps.e
+            s = 1 / alpha * (log(tan(PI / 4 + b / 2)) - k) + ellps.e
             * log(tan(PI / 4 + asin(ellps.e * sin(phi)) / 2));
-            phi = 2 * atan(exp(S)) - PI / 2;
+            phi = 2 * atan(exp(s)) - PI / 2;
         }
         return new double[] { phi, lambda };
Index: trunk/src/org/openstreetmap/josm/data/validation/TestError.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/validation/TestError.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/data/validation/TestError.java	(revision 8346)
@@ -40,5 +40,5 @@
     /** Deeper error description */
     private String description;
-    private String description_en;
+    private String descriptionEn;
     /** The affected primitives */
     private Collection<? extends OsmPrimitive> primitives;
@@ -66,5 +66,5 @@
         this.message = message;
         this.description = description;
-        this.description_en = description_en;
+        this.descriptionEn = description_en;
         this.primitives = primitives;
         this.highlighted = highlighted;
@@ -194,6 +194,6 @@
     public String getIgnoreSubGroup() {
         String ignorestring = getIgnoreGroup();
-        if (description_en != null) {
-            ignorestring += "_" + description_en;
+        if (descriptionEn != null) {
+            ignorestring += "_" + descriptionEn;
         }
         return ignorestring;
Index: trunk/src/org/openstreetmap/josm/data/validation/tests/DuplicateRelation.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/validation/tests/DuplicateRelation.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/data/validation/tests/DuplicateRelation.java	(revision 8346)
@@ -169,5 +169,5 @@
 
     /** MultiMap of all relations, regardless of keys */
-    private MultiMap<List<RelationMember>, OsmPrimitive> relations_nokeys;
+    private MultiMap<List<RelationMember>, OsmPrimitive> relationsNoKeys;
 
     /** List of keys without useful information */
@@ -186,5 +186,5 @@
         super.startTest(monitor);
         relations = new MultiMap<>(1000);
-        relations_nokeys = new MultiMap<>(1000);
+        relationsNoKeys = new MultiMap<>(1000);
     }
 
@@ -199,5 +199,5 @@
         }
         relations = null;
-        for (Set<OsmPrimitive> duplicated : relations_nokeys.values()) {
+        for (Set<OsmPrimitive> duplicated : relationsNoKeys.values()) {
             if (duplicated.size() > 1) {
                 TestError testError = new TestError(this, Severity.WARNING, tr("Relations with same members"), SAME_RELATION, duplicated);
@@ -205,5 +205,5 @@
             }
         }
-        relations_nokeys = null;
+        relationsNoKeys = null;
     }
 
@@ -218,5 +218,5 @@
         RelationPair rKey = new RelationPair(rMembers, rkeys);
         relations.put(rKey, r);
-        relations_nokeys.put(rMembers, r);
+        relationsNoKeys.put(rMembers, r);
     }
 
Index: trunk/src/org/openstreetmap/josm/data/validation/tests/UnconnectedWays.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/validation/tests/UnconnectedWays.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/data/validation/tests/UnconnectedWays.java	(revision 8346)
@@ -137,5 +137,5 @@
     private Set<MyWaySegment> ways;
     private QuadBuckets<Node> endnodes; // nodes at end of way
-    private QuadBuckets<Node> endnodes_highway; // nodes at end of way
+    private QuadBuckets<Node> endnodesHighway; // nodes at end of way
     private QuadBuckets<Node> middlenodes; // nodes in middle of way
     private Set<Node> othernodes; // nodes appearing at least twice
@@ -159,5 +159,5 @@
         ways = new HashSet<>();
         endnodes = new QuadBuckets<>();
-        endnodes_highway = new QuadBuckets<>();
+        endnodesHighway = new QuadBuckets<>();
         middlenodes = new QuadBuckets<>();
         othernodes = new HashSet<>();
@@ -176,5 +176,5 @@
                 }
                 for (Node en : s.nearbyNodes(mindist)) {
-                    if (en == null || !s.highway || !endnodes_highway.contains(en)) {
+                    if (en == null || !s.highway || !endnodesHighway.contains(en)) {
                         continue;
                     }
@@ -209,5 +209,5 @@
                     continue;
                 }
-                if (endnodes_highway.contains(en) && !s.highway && !s.w.concernsArea()) {
+                if (endnodesHighway.contains(en) && !s.highway && !s.w.concernsArea()) {
                     map.put(en, s.w);
                 } else if (endnodes.contains(en) && !s.w.concernsArea()) {
@@ -278,5 +278,5 @@
         ways = null;
         endnodes = null;
-        endnodes_highway = null;
+        endnodesHighway = null;
         middlenodes = null;
         othernodes = null;
@@ -389,5 +389,5 @@
             nearbyNodeCache = null;
             List<LatLon> bounds = this.getBounds(dist);
-            List<Node> found_nodes = endnodes_highway.search(new BBox(bounds.get(0), bounds.get(1)));
+            List<Node> found_nodes = endnodesHighway.search(new BBox(bounds.get(0), bounds.get(1)));
             found_nodes.addAll(endnodes.search(new BBox(bounds.get(0), bounds.get(1))));
 
@@ -448,5 +448,5 @@
             QuadBuckets<Node> set = endnodes;
             if (w.hasKey("highway") || w.hasKey("railway")) {
-                set = endnodes_highway;
+                set = endnodesHighway;
             }
             addNode(w.firstNode(), set);
@@ -458,5 +458,5 @@
         boolean m = middlenodes.contains(n);
         boolean e = endnodes.contains(n);
-        boolean eh = endnodes_highway.contains(n);
+        boolean eh = endnodesHighway.contains(n);
         boolean o = othernodes.contains(n);
         if (!m && !e && !o && !eh) {
@@ -467,5 +467,5 @@
                 endnodes.remove(n);
             } else if (eh) {
-                endnodes_highway.remove(n);
+                endnodesHighway.remove(n);
             } else {
                 middlenodes.remove(n);
Index: trunk/src/org/openstreetmap/josm/gui/NotificationManager.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/NotificationManager.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/gui/NotificationManager.java	(revision 8346)
@@ -73,6 +73,6 @@
     private static NotificationManager INSTANCE = null;
 
-    private final Color PANEL_SEMITRANSPARENT = new Color(224, 236, 249, 230);
-    private final Color PANEL_OPAQUE = new Color(224, 236, 249);
+    private static final Color PANEL_SEMITRANSPARENT = new Color(224, 236, 249, 230);
+    private static final Color PANEL_OPAQUE = new Color(224, 236, 249);
 
     public static synchronized NotificationManager getInstance() {
Index: trunk/src/org/openstreetmap/josm/gui/dialogs/ToggleDialog.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/dialogs/ToggleDialog.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/gui/dialogs/ToggleDialog.java	(revision 8346)
@@ -95,6 +95,6 @@
     public static final BooleanProperty PROP_DYNAMIC_BUTTONS = new BooleanProperty("dialog.dynamic.buttons", false);
 
-    private final transient ParametrizedEnumProperty<ButtonHidingType> PROP_BUTTON_HIDING = new ParametrizedEnumProperty<ToggleDialog.ButtonHidingType>(
-            ButtonHidingType.class, ButtonHidingType.DYNAMIC) {
+    private final transient ParametrizedEnumProperty<ButtonHidingType> propButtonHiding =
+            new ParametrizedEnumProperty<ToggleDialog.ButtonHidingType>(ButtonHidingType.class, ButtonHidingType.DYNAMIC) {
         @Override
         protected String getKey(String... params) {
@@ -107,5 +107,5 @@
             } catch (IllegalArgumentException e) {
                 // Legacy settings
-                return Boolean.parseBoolean(s)?ButtonHidingType.DYNAMIC:ButtonHidingType.ALWAYS_SHOWN;
+                return Boolean.parseBoolean(s) ? ButtonHidingType.DYNAMIC : ButtonHidingType.ALWAYS_SHOWN;
             }
         }
@@ -241,5 +241,5 @@
         isDocked = Main.pref.getBoolean(preferencePrefix+".docked", true);
         isCollapsed = Main.pref.getBoolean(preferencePrefix+".minimized", false);
-        buttonHiding = PROP_BUTTON_HIDING.get();
+        buttonHiding = propButtonHiding.get();
 
         /** show the minimize button */
@@ -490,5 +490,5 @@
         /** the label which displays the dialog's title **/
         private final JLabel lblTitle;
-        private final JComponent lblTitle_weak;
+        private final JComponent lblTitleWeak;
         /** the button which shows whether buttons are dynamic or not */
         private final JButton buttonsHide;
@@ -512,5 +512,5 @@
 
             // Cannot add the label directly since it would displace other elements on resize
-            lblTitle_weak = new JComponent() {
+            lblTitleWeak = new JComponent() {
                 @Override
                 public void paintComponent(Graphics g) {
@@ -518,7 +518,7 @@
                 }
             };
-            lblTitle_weak.setPreferredSize(new Dimension(Integer.MAX_VALUE,20));
-            lblTitle_weak.setMinimumSize(new Dimension(0,20));
-            add(lblTitle_weak, GBC.std().fill(GBC.HORIZONTAL));
+            lblTitleWeak.setPreferredSize(new Dimension(Integer.MAX_VALUE,20));
+            lblTitleWeak.setMinimumSize(new Dimension(0,20));
+            add(lblTitleWeak, GBC.std().fill(GBC.HORIZONTAL));
 
             buttonsHide = new JButton(ImageProvider.get("misc", buttonHiding != ButtonHidingType.ALWAYS_SHOWN
@@ -597,5 +597,5 @@
         public void setTitle(String title) {
             lblTitle.setText(title);
-            lblTitle_weak.repaint();
+            lblTitleWeak.repaint();
         }
 
@@ -767,5 +767,5 @@
     protected void setIsButtonHiding(ButtonHidingType val) {
         buttonHiding = val;
-        PROP_BUTTON_HIDING.put(val);
+        propButtonHiding.put(val);
         refreshHidingButtons();
     }
Index: trunk/src/org/openstreetmap/josm/gui/history/HistoryBrowserDialogManager.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/history/HistoryBrowserDialogManager.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/gui/history/HistoryBrowserDialogManager.java	(revision 8346)
@@ -33,5 +33,7 @@
  * @since 2019
  */
-public class HistoryBrowserDialogManager implements MapView.LayerChangeListener {
+public final class HistoryBrowserDialogManager implements MapView.LayerChangeListener {
+
+    private static final String WINDOW_GEOMETRY_PREF = HistoryBrowserDialogManager.class.getName() + ".geometry";
 
     private static HistoryBrowserDialogManager instance;
@@ -89,6 +91,4 @@
         return false;
     }
-
-    private final String WINDOW_GEOMETRY_PREF = getClass().getName() + ".geometry";
 
     protected void placeOnScreen(HistoryBrowserDialog dialog) {
Index: trunk/src/org/openstreetmap/josm/gui/layer/gpx/DateFilterPanel.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/layer/gpx/DateFilterPanel.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/gui/layer/gpx/DateFilterPanel.java	(revision 8346)
@@ -30,7 +30,7 @@
     private transient ActionListener filterAppliedListener;
 
-    private final String PREF_DATE_0;
-    private final String PREF_DATE_MIN;
-    private final String PREF_DATE_MAX;
+    private final String prefDate0;
+    private final String prefDateMin;
+    private final String prefDateMax;
 
     /**
@@ -41,7 +41,7 @@
     public DateFilterPanel(GpxLayer layer, String preferencePrefix, boolean enabled) {
         super(new GridBagLayout());
-        PREF_DATE_0 = preferencePrefix+".showzerotimestamp";
-        PREF_DATE_MIN = preferencePrefix+".mintime";
-        PREF_DATE_MAX = preferencePrefix+".maxtime";
+        prefDate0 = preferencePrefix+".showzerotimestamp";
+        prefDateMin = preferencePrefix+".mintime";
+        prefDateMax = preferencePrefix+".maxtime";
         this.layer = layer;
 
@@ -101,7 +101,7 @@
      */
     public void saveInPrefs() {
-        Main.pref.putLong(PREF_DATE_MIN, dateFrom.getDate().getTime());
-        Main.pref.putLong(PREF_DATE_MAX, dateTo.getDate().getTime());
-        Main.pref.put(PREF_DATE_0, noTimestampCb.isSelected());
+        Main.pref.putLong(prefDateMin, dateFrom.getDate().getTime());
+        Main.pref.putLong(prefDateMax, dateTo.getDate().getTime());
+        Main.pref.put(prefDate0, noTimestampCb.isSelected());
     }
 
@@ -111,9 +111,9 @@
      */
     public void loadFromPrefs() {
-        long t1 =Main.pref.getLong(PREF_DATE_MIN, 0);
+        long t1 =Main.pref.getLong(prefDateMin, 0);
         if (t1!=0) dateFrom.setDate(new Date(t1));
-        long t2 =Main.pref.getLong(PREF_DATE_MAX, 0);
+        long t2 =Main.pref.getLong(prefDateMax, 0);
         if (t2!=0) dateTo.setDate(new Date(t2));
-        noTimestampCb.setSelected(Main.pref.getBoolean(PREF_DATE_0, false));
+        noTimestampCb.setSelected(Main.pref.getBoolean(prefDate0, false));
     }
 
Index: trunk/src/org/openstreetmap/josm/gui/mappaint/ElemStyle.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/mappaint/ElemStyle.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/gui/mappaint/ElemStyle.java	(revision 8346)
@@ -23,21 +23,21 @@
     public static final String[] REPEAT_IMAGE_KEYS = {REPEAT_IMAGE, REPEAT_IMAGE_WIDTH, REPEAT_IMAGE_HEIGHT, REPEAT_IMAGE_OPACITY, null, null};
 
-    public float major_z_index;
-    public float z_index;
-    public float object_z_index;
+    public float majorZIndex;
+    public float zIndex;
+    public float objectZIndex;
     public boolean isModifier;  // false, if style can serve as main style for the
     // primitive; true, if it is a highlight or modifier
 
     public ElemStyle(float major_z_index, float z_index, float object_z_index, boolean isModifier) {
-        this.major_z_index = major_z_index;
-        this.z_index = z_index;
-        this.object_z_index = object_z_index;
+        this.majorZIndex = major_z_index;
+        this.zIndex = z_index;
+        this.objectZIndex = object_z_index;
         this.isModifier = isModifier;
     }
 
     protected ElemStyle(Cascade c, float default_major_z_index) {
-        major_z_index = c.get(MAJOR_Z_INDEX, default_major_z_index, Float.class);
-        z_index = c.get(Z_INDEX, 0f, Float.class);
-        object_z_index = c.get(OBJECT_Z_INDEX, 0f, Float.class);
+        majorZIndex = c.get(MAJOR_Z_INDEX, default_major_z_index, Float.class);
+        zIndex = c.get(Z_INDEX, 0f, Float.class);
+        objectZIndex = c.get(OBJECT_Z_INDEX, 0f, Float.class);
         isModifier = c.get(MODIFIER, false, Boolean.class);
     }
@@ -208,7 +208,7 @@
             return false;
         ElemStyle s = (ElemStyle) o;
-        return major_z_index == s.major_z_index &&
-                z_index == s.z_index &&
-                object_z_index == s.object_z_index &&
+        return majorZIndex == s.majorZIndex &&
+                zIndex == s.zIndex &&
+                objectZIndex == s.objectZIndex &&
                 isModifier == s.isModifier;
     }
@@ -217,7 +217,7 @@
     public int hashCode() {
         int hash = 5;
-        hash = 41 * hash + Float.floatToIntBits(this.major_z_index);
-        hash = 41 * hash + Float.floatToIntBits(this.z_index);
-        hash = 41 * hash + Float.floatToIntBits(this.object_z_index);
+        hash = 41 * hash + Float.floatToIntBits(this.majorZIndex);
+        hash = 41 * hash + Float.floatToIntBits(this.zIndex);
+        hash = 41 * hash + Float.floatToIntBits(this.objectZIndex);
         hash = 41 * hash + (isModifier ? 1 : 0);
         return hash;
@@ -226,5 +226,5 @@
     @Override
     public String toString() {
-        return String.format("z_idx=[%s/%s/%s] ", major_z_index, z_index, object_z_index) + (isModifier ? "modifier " : "");
+        return String.format("z_idx=[%s/%s/%s] ", majorZIndex, zIndex, objectZIndex) + (isModifier ? "modifier " : "");
     }
 }
Index: trunk/src/org/openstreetmap/josm/gui/mappaint/LineElemStyle.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/mappaint/LineElemStyle.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/gui/mappaint/LineElemStyle.java	(revision 8346)
@@ -47,9 +47,9 @@
 
         public final String prefix;
-        public final float default_major_z_index;
+        public final float defaultMajorZIndex;
 
         LineType(String prefix, float default_major_z_index) {
             this.prefix = prefix;
-            this.default_major_z_index = default_major_z_index;
+            this.defaultMajorZIndex = default_major_z_index;
         }
     }
@@ -258,5 +258,5 @@
         }
 
-        return new LineElemStyle(c, type.default_major_z_index, line, color, dashesLine, dashesBackground, offset, realWidth);
+        return new LineElemStyle(c, type.defaultMajorZIndex, line, color, dashesLine, dashesBackground, offset, realWidth);
     }
 
Index: trunk/src/org/openstreetmap/josm/io/DiffResultProcessor.java
===================================================================
--- trunk/src/org/openstreetmap/josm/io/DiffResultProcessor.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/io/DiffResultProcessor.java	(revision 8346)
@@ -35,6 +35,6 @@
 
     private static class DiffResultEntry {
-        public long new_id;
-        public int new_version;
+        private long newId;
+        private int newVersion;
     }
 
@@ -128,5 +128,5 @@
                 processed.add(p);
                 if (!p.isDeleted()) {
-                    p.setOsmId(entry.new_id, entry.new_version);
+                    p.setOsmId(entry.newId, entry.newVersion);
                     p.setVisible(true);
                 } else {
@@ -174,8 +174,8 @@
                     DiffResultEntry entry = new DiffResultEntry();
                     if (atts.getValue("new_id") != null) {
-                        entry.new_id = Long.parseLong(atts.getValue("new_id"));
+                        entry.newId = Long.parseLong(atts.getValue("new_id"));
                     }
                     if (atts.getValue("new_version") != null) {
-                        entry.new_version = Integer.parseInt(atts.getValue("new_version"));
+                        entry.newVersion = Integer.parseInt(atts.getValue("new_version"));
                     }
                     diffResults.put(id, entry);
Index: trunk/src/org/openstreetmap/josm/io/NmeaReader.java
===================================================================
--- trunk/src/org/openstreetmap/josm/io/NmeaReader.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/io/NmeaReader.java	(revision 8346)
@@ -154,8 +154,8 @@
     }
     public int getParserZeroCoordinates() {
-        return ps.zero_coord;
+        return ps.zeroCoord;
     }
     public int getParserChecksumErrors() {
-        return ps.checksum_errors+ps.no_checksum;
+        return ps.checksumErrors+ps.noChecksum;
     }
     public int getParserMalformed() {
@@ -180,5 +180,5 @@
                 return;
             sb.append((char)loopstart_char);
-            ps.p_Date="010100"; // TODO date problem
+            ps.pDate="010100"; // TODO date problem
             while(true) {
                 // don't load unparsable files completely to memory
@@ -209,14 +209,14 @@
     private static class NMEAParserState {
         protected Collection<WayPoint> waypoints = new ArrayList<>();
-        protected String p_Time;
-        protected String p_Date;
-        protected WayPoint p_Wp;
-
-        protected int success = 0; // number of successfully parsend sentences
+        protected String pTime;
+        protected String pDate;
+        protected WayPoint pWp;
+
+        protected int success = 0; // number of successfully parsed sentences
         protected int malformed = 0;
-        protected int checksum_errors = 0;
-        protected int no_checksum = 0;
+        protected int checksumErrors = 0;
+        protected int noChecksum = 0;
         protected int unknown = 0;
-        protected int zero_coord = 0;
+        protected int zeroCoord = 0;
     }
 
@@ -243,10 +243,10 @@
                 }
                 if (Integer.parseInt(chkstrings[1].substring(0,2),16) != chk) {
-                    ps.checksum_errors++;
-                    ps.p_Wp=null;
+                    ps.checksumErrors++;
+                    ps.pWp=null;
                     return false;
                 }
             } else {
-                ps.no_checksum++;
+                ps.noChecksum++;
             }
             // now for the content
@@ -254,6 +254,6 @@
             String accu;
 
-            WayPoint currentwp = ps.p_Wp;
-            String currentDate = ps.p_Date;
+            WayPoint currentwp = ps.pWp;
+            String currentDate = ps.pDate;
 
             // handle the packet content
@@ -271,5 +271,5 @@
 
                 if ((latLon.lat()==0.0) && (latLon.lon()==0.0)) {
-                    ps.zero_coord++;
+                    ps.zeroCoord++;
                     return false;
                 }
@@ -279,9 +279,9 @@
                 Date d = readTime(currentDate+accu);
 
-                if((ps.p_Time==null) || (currentwp==null) || !ps.p_Time.equals(accu)) {
+                if((ps.pTime==null) || (currentwp==null) || !ps.pTime.equals(accu)) {
                     // this node is newer than the previous, create a new waypoint.
                     // no matter if previous WayPoint was null, we got something
                     // better now.
-                    ps.p_Time=accu;
+                    ps.pTime=accu;
                     currentwp = new WayPoint(latLon);
                 }
@@ -384,6 +384,6 @@
                         e[GPRMC.LENGTH_EAST.position]
                 );
-                if((latLon.lat()==0.0) && (latLon.lon()==0.0)) {
-                    ps.zero_coord++;
+                if(latLon.lat()==0.0 && latLon.lon()==0.0) {
+                    ps.zeroCoord++;
                     return false;
                 }
@@ -394,7 +394,7 @@
                 Date d = readTime(currentDate+time);
 
-                if((ps.p_Time==null) || (currentwp==null) || !ps.p_Time.equals(time)) {
+                if(ps.pTime==null || currentwp==null || !ps.pTime.equals(time)) {
                     // this node is newer than the previous, create a new waypoint.
-                    ps.p_Time=time;
+                    ps.pTime=time;
                     currentwp = new WayPoint(latLon);
                 }
@@ -426,10 +426,10 @@
                 return false;
             }
-            ps.p_Date = currentDate;
-            if(ps.p_Wp != currentwp) {
-                if(ps.p_Wp!=null) {
-                    ps.p_Wp.setTime();
-                }
-                ps.p_Wp = currentwp;
+            ps.pDate = currentDate;
+            if(ps.pWp != currentwp) {
+                if(ps.pWp!=null) {
+                    ps.pWp.setTime();
+                }
+                ps.pWp = currentwp;
                 ps.waypoints.add(currentwp);
                 ps.success++;
@@ -441,5 +441,5 @@
             // out of bounds and such
             ps.malformed++;
-            ps.p_Wp=null;
+            ps.pWp=null;
             return false;
         }
Index: trunk/src/org/openstreetmap/josm/io/NoteWriter.java
===================================================================
--- trunk/src/org/openstreetmap/josm/io/NoteWriter.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/io/NoteWriter.java	(revision 8346)
@@ -23,5 +23,5 @@
 public class NoteWriter extends XmlWriter {
 
-    private final DateFormat ISO8601_FORMAT = DateUtils.newIsoDateTimeFormat();
+    private final DateFormat iso8601Format = DateUtils.newIsoDateTimeFormat();
 
     /**
@@ -53,7 +53,7 @@
             out.print("lat=\"" + note.getLatLon().lat() + "\" ");
             out.print("lon=\"" + note.getLatLon().lon() + "\" ");
-            out.print("created_at=\"" + ISO8601_FORMAT.format(note.getCreatedAt()) + "\" ");
+            out.print("created_at=\"" + iso8601Format.format(note.getCreatedAt()) + "\" ");
             if (note.getClosedAt() != null) {
-                out.print("closed_at=\"" + ISO8601_FORMAT.format(note.getClosedAt()) + "\" ");
+                out.print("closed_at=\"" + iso8601Format.format(note.getClosedAt()) + "\" ");
             }
 
@@ -72,5 +72,5 @@
         out.print("    <comment");
         out.print(" action=\"" + comment.getNoteAction() + "\" ");
-        out.print("timestamp=\"" + ISO8601_FORMAT.format(comment.getCommentTimestamp()) + "\" ");
+        out.print("timestamp=\"" + iso8601Format.format(comment.getCommentTimestamp()) + "\" ");
         if (comment.getUser() != null && !comment.getUser().equals(User.getAnonymous())) {
             out.print("uid=\"" + comment.getUser().getId() + "\" ");
Index: trunk/src/org/openstreetmap/josm/data/osm/QuadBuckets.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/osm/QuadBuckets.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/data/osm/QuadBuckets.java	(revision 8346)
@@ -304,5 +304,5 @@
                 return;
             else if (bbox().bounds(search_bbox)) {
-                buckets.search_cache = this;
+                buckets.searchCache = this;
             }
 
@@ -393,5 +393,5 @@
 
     private QBLevel<T> root;
-    private QBLevel<T> search_cache;
+    private QBLevel<T> searchCache;
     private int size;
 
@@ -406,5 +406,5 @@
     public final void clear() {
         root = new QBLevel<>(this);
-        search_cache = null;
+        searchCache = null;
         size = 0;
     }
@@ -460,5 +460,5 @@
         @SuppressWarnings("unchecked")
         T t = (T) o;
-        search_cache = null; // Search cache might point to one of removed buckets
+        searchCache = null; // Search cache might point to one of removed buckets
         QBLevel<T> bucket = root.findBucket(t.getBBox());
         if (bucket.remove_content(t)) {
@@ -496,7 +496,7 @@
 
     class QuadBucketIterator implements Iterator<T> {
-        private QBLevel<T> current_node;
-        private int content_index;
-        private int iterated_over;
+        private QBLevel<T> currentNode;
+        private int contentIndex;
+        private int iteratedOver;
 
         final QBLevel<T> next_content_node(QBLevel<T> q) {
@@ -514,9 +514,9 @@
         public QuadBucketIterator(QuadBuckets<T> qb) {
             if (!qb.root.hasChildren() || qb.root.hasContent()) {
-                current_node = qb.root;
+                currentNode = qb.root;
             } else {
-                current_node = next_content_node(qb.root);
-            }
-            iterated_over = 0;
+                currentNode = next_content_node(qb.root);
+            }
+            iteratedOver = 0;
         }
 
@@ -529,16 +529,16 @@
 
         T peek() {
-            if (current_node == null)
+            if (currentNode == null)
                 return null;
-            while ((current_node.content == null) || (content_index >= current_node.content.size())) {
-                content_index = 0;
-                current_node = next_content_node(current_node);
-                if (current_node == null) {
+            while ((currentNode.content == null) || (contentIndex >= currentNode.content.size())) {
+                contentIndex = 0;
+                currentNode = next_content_node(currentNode);
+                if (currentNode == null) {
                     break;
                 }
             }
-            if (current_node == null || current_node.content == null)
+            if (currentNode == null || currentNode.content == null)
                 return null;
-            return current_node.content.get(content_index);
+            return currentNode.content.get(contentIndex);
         }
 
@@ -546,6 +546,6 @@
         public T next() {
             T ret = peek();
-            content_index++;
-            iterated_over++;
+            contentIndex++;
+            iteratedOver++;
             return ret;
         }
@@ -557,7 +557,7 @@
             // 2. move the index back since we removed
             //    an element
-            content_index--;
+            contentIndex--;
             T object = peek();
-            current_node.remove_content(object);
+            currentNode.remove_content(object);
         }
     }
@@ -581,21 +581,21 @@
         List<T> ret = new ArrayList<>();
         // Doing this cuts down search cost on a real-life data set by about 25%
-        if (search_cache == null) {
-            search_cache = root;
+        if (searchCache == null) {
+            searchCache = root;
         }
         // Walk back up the tree when the last search spot can not cover the current search
-        while (search_cache != null && !search_cache.bbox().bounds(search_bbox)) {
-            search_cache = search_cache.parent;
-        }
-
-        if (search_cache == null) {
-            search_cache = root;
+        while (searchCache != null && !searchCache.bbox().bounds(search_bbox)) {
+            searchCache = searchCache.parent;
+        }
+
+        if (searchCache == null) {
+            searchCache = root;
             Main.info("bbox: " + search_bbox + " is out of the world");
         }
 
-        // Save parent because search_cache might change during search call
-        QBLevel<T> tmp = search_cache.parent;
-
-        search_cache.search(search_bbox, ret);
+        // Save parent because searchCache might change during search call
+        QBLevel<T> tmp = searchCache.parent;
+
+        searchCache.search(search_bbox, ret);
 
         // A way that spans this bucket may be stored in one
Index: trunk/src/org/openstreetmap/josm/tools/Diff.java
===================================================================
--- trunk/src/org/openstreetmap/josm/tools/Diff.java	(revision 8345)
+++ trunk/src/org/openstreetmap/josm/tools/Diff.java	(revision 8346)
@@ -16,5 +16,5 @@
  *
  * Revision 1.13  2009/12/07 17:43:17  stuart
  * Compute equiv_max for int[] ctor
  *
  * Revision 1.12  2009/12/07 17:34:46  stuart
@@ -102,5 +102,5 @@
     /** 1 more than the maximum equivalence value used for this or its
      sibling file. */
-    private int equiv_max = 1;
+    private int equivMax = 1;
 
     /** When set to true, the comparison uses a heuristic to speed it up.
@@ -111,5 +111,5 @@
     /** When set to true, the algorithm returns a guarranteed minimal
       set of changes.  This makes things slower, sometimes much slower. */
-    public boolean no_discards = false;
+    public boolean noDiscards = false;
 
     private int[] xvec, yvec; /* Vectors being compared. */
@@ -352,9 +352,9 @@
         if (xoff == xlim) {
             while (yoff < ylim) {
-                filevec[1].changed_flag[1+filevec[1].realindexes[yoff++]] = true;
+                filevec[1].changedFlag[1+filevec[1].realindexes[yoff++]] = true;
             }
         } else if (yoff == ylim) {
             while (xoff < xlim) {
-                filevec[0].changed_flag[1+filevec[0].realindexes[xoff++]] = true;
+                filevec[0].changedFlag[1+filevec[0].realindexes[xoff++]] = true;
             }
         } else {
@@ -524,12 +524,12 @@
 
         int diags =
-            filevec[0].nondiscarded_lines + filevec[1].nondiscarded_lines + 3;
+            filevec[0].nondiscardedLines + filevec[1].nondiscardedLines + 3;
         fdiag = new int[diags];
-        fdiagoff = filevec[1].nondiscarded_lines + 1;
+        fdiagoff = filevec[1].nondiscardedLines + 1;
         bdiag = new int[diags];
-        bdiagoff = filevec[1].nondiscarded_lines + 1;
-
-        compareseq (0, filevec[0].nondiscarded_lines,
-                0, filevec[1].nondiscarded_lines);
+        bdiagoff = filevec[1].nondiscardedLines + 1;
+
+        compareseq (0, filevec[0].nondiscardedLines,
+                0, filevec[1].nondiscardedLines);
         fdiag = null;
         bdiag = null;
@@ -543,8 +543,8 @@
        of `struct change's -- an edit script.  */
         return bld.build_script(
-                filevec[0].changed_flag,
-                filevec[0].buffered_lines,
-                filevec[1].changed_flag,
-                filevec[1].buffered_lines
+                filevec[0].changedFlag,
+                filevec[0].bufferedLines,
+                filevec[1].changedFlag,
+                filevec[1].bufferedLines
         );
 
@@ -607,5 +607,5 @@
                Allocate an extra element, always zero, at each end of each vector.
              */
-            changed_flag = new boolean[buffered_lines + 2];
+            changedFlag = new boolean[bufferedLines + 2];
         }
 
@@ -615,6 +615,6 @@
          */
         int[] equivCount() {
-            int[] equiv_count = new int[equiv_max];
-            for (int i = 0; i < buffered_lines; ++i) {
+            int[] equiv_count = new int[equivMax];
+            for (int i = 0; i < bufferedLines; ++i) {
                 ++equiv_count[equivs[i]];
             }
@@ -658,5 +658,5 @@
          */
         private byte[] discardable(final int[] counts) {
-            final int end = buffered_lines;
+            final int end = bufferedLines;
             final byte[] discards = new byte[end];
             final int[] equivs = this.equivs;
@@ -692,5 +692,5 @@
          */
         private void filterDiscards(final byte[] discards) {
-            final int end = buffered_lines;
+            final int end = bufferedLines;
 
             for (int i = 0; i < end; i++)
@@ -808,22 +808,22 @@
          */
         private void discard(final byte[] discards) {
-            final int end = buffered_lines;
+            final int end = bufferedLines;
             int j = 0;
             for (int i = 0; i < end; ++i)
-                if (no_discards || discards[i] == 0)
+                if (noDiscards || discards[i] == 0)
                 {
                     undiscarded[j] = equivs[i];
                     realindexes[j++] = i;
                 } else {
-                    changed_flag[1+i] = true;
-                }
-            nondiscarded_lines = j;
+                    changedFlag[1+i] = true;
+                }
+            nondiscardedLines = j;
         }
 
         FileData(int length) {
-            buffered_lines = length;
+            bufferedLines = length;
             equivs = new int[length];
-            undiscarded = new int[buffered_lines];
-            realindexes = new int[buffered_lines];
+            undiscarded = new int[bufferedLines];
+            realindexes = new int[bufferedLines];
         }
 
@@ -834,5 +834,5 @@
                 Integer ir = h.get(data[i]);
                 if (ir == null) {
-                    h.put(data[i],equivs[i] = equiv_max++);
+                    h.put(data[i],equivs[i] = equivMax++);
                 } else {
                     equivs[i] = ir.intValue();
@@ -855,9 +855,9 @@
 
         void shift_boundaries(FileData f) {
-            final boolean[] changed = changed_flag;
-            final boolean[] other_changed = f.changed_flag;
+            final boolean[] changed = changedFlag;
+            final boolean[] other_changed = f.changedFlag;
             int i = 0;
             int j = 0;
-            int i_end = buffered_lines;
+            int i_end = bufferedLines;
             int preceding = -1;
             int other_preceding = -1;
@@ -930,5 +930,5 @@
 
         /** Number of elements (lines) in this file. */
-        private final int buffered_lines;
+        private final int bufferedLines;
 
         /** Vector, indexed by line number, containing an equivalence code for
@@ -946,10 +946,10 @@
 
         /** Total number of nondiscarded lines. */
-        private int         nondiscarded_lines;
+        private int         nondiscardedLines;
 
         /** Array, indexed by real origin-1 line number,
            containing true for a line that is an insertion or a deletion.
            The results of comparison are stored here.  */
-        private boolean[]       changed_flag;
+        private boolean[]       changedFlag;
     }
 }
@@ -16,5 +16,5 @@
  *
  * Revision 1.13  2009/12/07 17:43:17  stuart
- * Compute equiv_max for int[] ctor
+ * Compute equivMax for int[] ctor
  *
  * Revision 1.12  2009/12/07 17:34:46  stuart
